@@ -210,7 +210,10 @@ class API:
         url: str
             A URL to send to the user
         """
-        resp = self.simple_req_no_json("get", "invite", data={"admin": admin})
+        if admin:
+            resp = self.simple_req_no_json("get", "invite?admin=true", data={"admin": True})
+        else:
+            resp = self.simple_req_no_json("get", "invite", data={"admin": False})
         return resp.headers["Content-Location"]
 
 
@@ -281,7 +284,7 @@ class API:
             if st == 'errored':
                 raise RuntimeError("Bad status")
             elif st == 'completed':
-                return json.loads(token_res['result'])
+                return token_res['result']
 
 
     def wait_token_plot(self, token):
@@ -329,6 +332,17 @@ class API:
         return self.simple_req('get', 'processes')
 
 
+    def get_metadata(self, proc):
+        """Retrieve metadata for specified process
+
+        Returns
+        -------
+        metadata: dict
+            A dictionary containing meta data.
+        """
+        return self.simple_req('get','processes/'+proc)
+
+
     def request_hist(self, proc, data):
         """Submit histogram request to server.
 
@@ -365,4 +379,4 @@ class API:
         info: dict
             A dictionary with the information on a specific token.
         """
-        return self.simple_req('get', f'token/{token}')
\ No newline at end of file
+        return self.simple_req('get', f'token/{token}')
